# `aiida-pseudo`

AiiDA plugin that simplifies working with pseudopotentials.

[![PyPI version](https://badge.fury.io/py/aiida-pseudo.svg)](https://badge.fury.io/py/aiida-pseudo)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/aiida-pseudo.svg)](https://pypi.python.org/pypi/aiida-pseudo/)
[![Build Status](https://github.com/aiidateam/aiida-pseudo/workflows/continuous-integration/badge.svg?event=push)](https://github.com/aiidateam/aiida-pseudo/actions)
[![Docs status](https://readthedocs.org/projects/aiida-pseudo/badge)](http://aiida-pseudo.readthedocs.io/)

For more information on how to install and use the package, please consult [the documentation](http://aiida-pseudo.readthedocs.io/).

## License
The `aiida-pseudo` plugin package is released under the MIT license.
See the `LICENSE.txt` file for more details.

## Acknowledgements
We acknowledge support from:

<table>
    <tr>
        <td><a href="http://nccr-marvel.ch/">NCCR MARVEL</a> funded by the Swiss National Science Foundation</td>
        <td><a href="http://www.max-centre.eu/">EU Centre of Excellence MaX</a> (Horizon 2020 EINFRA-5, Grant No. 676598)</td>
        <td><a href="https://www.materialscloud.org/swissuniversities">swissuniversities</a> P-5 project "Materials Cloud"</td>
    </tr>
    <tr>
        <td valign="middle"><img src="https://raw.githubusercontent.com/aiidateam/aiida-quantumespresso/develop/docs/source/images/MARVEL.png" /></td>
        <td valign="middle"><img src="https://raw.githubusercontent.com/aiidateam/aiida-quantumespresso/develop/docs/source/images/MaX.png" /></td>
        <td valign="middle"><img src="https://raw.githubusercontent.com/aiidateam/aiida-quantumespresso/develop/docs/source/images/swissuniversities.png" /></td>
    </tr>
</table>
